---
hide:
  - toc
social:
  cards_layout_options:
    title: "Welcome to valency-anndata"
---

# Welcome to valency-anndata

**valency-anndata** (pronounced "valencian data") is an experimental toolkit for exploration of vote matrices of "valence data" (_participants x statements_), also known as _polislike_ data.

We aim to grow and support a community of data scientists, statisticians, software developers, UI designers, and deliberative process facilitators who wish to democratize insights from valence data, and strengthen democratic self-governance.

![diagram of one workflow of valencyann-data](assets/valency-anndata-flow.alpha.png)

## Attribution

We build on the following tools, standards, and best-practices:

- [polis][], a real-time system for gathering, analyzing and understanding what large groups of people think in their own words, enabled by advanced statistics and machine learning.
- [anndata][], a tool for working with 2D annotated data matrices,
- [scanpy][], a toolkit for exploring gene expression matrices (_cells x genes_), and
- [the scverse][], the community that has grown around the above Python tooling.

We are inspired by the solutions to comparable challenges that are being resolved in the single-cell -omics community, we aspire to bring comparable rigour, collaboration, and reproducibility to the social sciences and its corresponding valence data.

<!-- Links -->
   [polis]: https://compdemocracy.org/Welcome
   [anndata]: https://scanpy.readthedocs.io/en/stable/
   [scanpy]: https://scanpy.readthedocs.io/en/latest/
   [the scverse]: https://scverse.org/